/* ssl_md5.c */
/* Copyright (C) 1995 Eric Young (eay@mincom.oz.au).
 * All rights reserved.
 * Copyright remains Eric Young's, and as such any Copyright notices in
 * the code are not to be removed.
 * See the COPYRIGHT file in the SSLeay distribution for more details.
 */

#define MD5_MAC_SIZE    16

#ifdef PROTO
void ssl_compute_md5_mac(SSL *s, unsigned char *md);
#else
void ssl_compute_md5_mac();
#endif
